@@ -32,42 +32,12 @@ import frozendict  # noqa: F401
 
 from snaptrade_client import schemas  # noqa: F401
 
-from snaptrade_client.model.exchange import Exchange as ExchangeSchema
 from snaptrade_client.model.model400_failed_request_response import Model400FailedRequestResponse as Model400FailedRequestResponseSchema
-from snaptrade_client.model.stop_price import StopPrice as StopPriceSchema
-from snaptrade_client.model.time_in_force import TimeInForce as TimeInForceSchema
-from snaptrade_client.model.security_type import SecurityType as SecurityTypeSchema
-from snaptrade_client.model.order_type import OrderType as OrderTypeSchema
-from snaptrade_client.model.price import Price as PriceSchema
-from snaptrade_client.model.action import Action as ActionSchema
-from snaptrade_client.model.options_symbol import OptionsSymbol as OptionsSymbolSchema
-from snaptrade_client.model.filled_units import FilledUnits as FilledUnitsSchema
-from snaptrade_client.model.cancelled_units import CancelledUnits as CancelledUnitsSchema
 from snaptrade_client.model.account_order_record import AccountOrderRecord as AccountOrderRecordSchema
-from snaptrade_client.model.currency import Currency as CurrencySchema
-from snaptrade_client.model.underlying_symbol import UnderlyingSymbol as UnderlyingSymbolSchema
-from snaptrade_client.model.us_exchange import USExchange as USExchangeSchema
-from snaptrade_client.model.universal_symbol import UniversalSymbol as UniversalSymbolSchema
-from snaptrade_client.model.open_units import OpenUnits as OpenUnitsSchema
-from snaptrade_client.model.account_order_record_status import AccountOrderRecordStatus as AccountOrderRecordStatusSchema
+from snaptrade_client.model.validated_trade_body import ValidatedTradeBody as ValidatedTradeBodySchema
 
-from snaptrade_client.type.account_order_record_status import AccountOrderRecordStatus
-from snaptrade_client.type.time_in_force import TimeInForce
-from snaptrade_client.type.security_type import SecurityType
-from snaptrade_client.type.filled_units import FilledUnits
+from snaptrade_client.type.validated_trade_body import ValidatedTradeBody
 from snaptrade_client.type.model400_failed_request_response import Model400FailedRequestResponse
-from snaptrade_client.type.stop_price import StopPrice
-from snaptrade_client.type.currency import Currency
-from snaptrade_client.type.price import Price
-from snaptrade_client.type.order_type import OrderType
-from snaptrade_client.type.action import Action
-from snaptrade_client.type.cancelled_units import CancelledUnits
-from snaptrade_client.type.options_symbol import OptionsSymbol
-from snaptrade_client.type.exchange import Exchange
-from snaptrade_client.type.us_exchange import USExchange
-from snaptrade_client.type.underlying_symbol import UnderlyingSymbol
-from snaptrade_client.type.open_units import OpenUnits
-from snaptrade_client.type.universal_symbol import UniversalSymbol
 from snaptrade_client.type.account_order_record import AccountOrderRecord
 
 from . import path
@@ -134,6 +104,16 @@ request_path_trade_id = api_client.PathParameter(
     schema=TradeIdSchema,
     required=True,
 )
+# body param
+SchemaForRequestBodyApplicationJson = ValidatedTradeBodySchema
+
+
+request_body_validated_trade_body = api_client.RequestBody(
+    content={
+        'application/json': api_client.MediaType(
+            schema=SchemaForRequestBodyApplicationJson),
+    },
+)
 _auth = [
     'PartnerClientId',
     'PartnerSignature',
@@ -211,15 +191,21 @@ class BaseApi(api_client.Api):
 
     def _place_order_mapped_args(
         self,
+        body: typing.Optional[ValidatedTradeBody] = None,
         trade_id: typing.Optional[str] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
+        wait_to_confirm: typing.Optional[typing.Optional[bool]] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
     ) -> api_client.MappedArgs:
         args: api_client.MappedArgs = api_client.MappedArgs()
         _query_params = {}
         _path_params = {}
+        _body = {}
+        if wait_to_confirm is not None:
+            _body["wait_to_confirm"] = wait_to_confirm
+        args.body = body if body is not None else _body
         if user_id is not None:
             _query_params["userId"] = user_id
         if user_secret is not None:
@@ -232,12 +218,15 @@ class BaseApi(api_client.Api):
 
     async def _aplace_order_oapg(
         self,
+        body: typing.Any = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
+        content_type: str = 'application/json',
         stream: bool = False,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -286,21 +275,36 @@ class BaseApi(api_client.Api):
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
         method = 'post'.upper()
+        _headers.add('Content-Type', content_type)
+    
+        _fields = None
+        _body = None
         request_before_hook(
             resource_path=used_path,
             method=method,
             configuration=self.api_client.configuration,
+            body=body,
             auth_settings=_auth,
             headers=_headers,
         )
+        if body is not schemas.unset:
+            serialized_data = request_body_validated_trade_body.serialize(body, content_type)
+            if 'fields' in serialized_data:
+                _fields = serialized_data['fields']
+            elif 'body' in serialized_data:
+                _body = serialized_data['body']
     
         response = await self.api_client.async_call_api(
             resource_path=used_path,
             method=method,
             headers=_headers,
+            fields=_fields,
+            serialized_body=_body,
+            body=body,
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
+            **kwargs
         )
     
         if stream:
@@ -359,11 +363,13 @@ class BaseApi(api_client.Api):
 
     def _place_order_oapg(
         self,
+        body: typing.Any = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
+        content_type: str = 'application/json',
         stream: bool = False,
     ) -> typing.Union[
         ApiResponseFor200,
@@ -412,18 +418,32 @@ class BaseApi(api_client.Api):
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
         method = 'post'.upper()
+        _headers.add('Content-Type', content_type)
+    
+        _fields = None
+        _body = None
         request_before_hook(
             resource_path=used_path,
             method=method,
             configuration=self.api_client.configuration,
+            body=body,
             auth_settings=_auth,
             headers=_headers,
         )
+        if body is not schemas.unset:
+            serialized_data = request_body_validated_trade_body.serialize(body, content_type)
+            if 'fields' in serialized_data:
+                _fields = serialized_data['fields']
+            elif 'body' in serialized_data:
+                _body = serialized_data['body']
     
         response = self.api_client.call_api(
             resource_path=used_path,
             method=method,
             headers=_headers,
+            fields=_fields,
+            serialized_body=_body,
+            body=body,
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
@@ -458,33 +478,42 @@ class PlaceOrder(BaseApi):
 
     async def aplace_order(
         self,
+        body: typing.Optional[ValidatedTradeBody] = None,
         trade_id: typing.Optional[str] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
+        wait_to_confirm: typing.Optional[typing.Optional[bool]] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
         AsyncGeneratorResponse,
     ]:
         args = self._place_order_mapped_args(
+            body=body,
             query_params=query_params,
             path_params=path_params,
             trade_id=trade_id,
             user_id=user_id,
             user_secret=user_secret,
+            wait_to_confirm=wait_to_confirm,
         )
         return await self._aplace_order_oapg(
+            body=args.body,
             query_params=args.query,
             path_params=args.path,
+            **kwargs,
         )
     
     def place_order(
         self,
+        body: typing.Optional[ValidatedTradeBody] = None,
         trade_id: typing.Optional[str] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
+        wait_to_confirm: typing.Optional[typing.Optional[bool]] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
     ) -> typing.Union[
@@ -492,13 +521,16 @@ class PlaceOrder(BaseApi):
         api_client.ApiResponseWithoutDeserialization,
     ]:
         args = self._place_order_mapped_args(
+            body=body,
             query_params=query_params,
             path_params=path_params,
             trade_id=trade_id,
             user_id=user_id,
             user_secret=user_secret,
+            wait_to_confirm=wait_to_confirm,
         )
         return self._place_order_oapg(
+            body=args.body,
             query_params=args.query,
             path_params=args.path,
         )
@@ -508,33 +540,42 @@ class ApiForpost(BaseApi):
 
     async def apost(
         self,
+        body: typing.Optional[ValidatedTradeBody] = None,
         trade_id: typing.Optional[str] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
+        wait_to_confirm: typing.Optional[typing.Optional[bool]] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
         AsyncGeneratorResponse,
     ]:
         args = self._place_order_mapped_args(
+            body=body,
             query_params=query_params,
             path_params=path_params,
             trade_id=trade_id,
             user_id=user_id,
             user_secret=user_secret,
+            wait_to_confirm=wait_to_confirm,
         )
         return await self._aplace_order_oapg(
+            body=args.body,
             query_params=args.query,
             path_params=args.path,
+            **kwargs,
         )
     
     def post(
         self,
+        body: typing.Optional[ValidatedTradeBody] = None,
         trade_id: typing.Optional[str] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
+        wait_to_confirm: typing.Optional[typing.Optional[bool]] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
     ) -> typing.Union[
@@ -542,13 +583,16 @@ class ApiForpost(BaseApi):
         api_client.ApiResponseWithoutDeserialization,
     ]:
         args = self._place_order_mapped_args(
+            body=body,
             query_params=query_params,
             path_params=path_params,
             trade_id=trade_id,
             user_id=user_id,
             user_secret=user_secret,
+            wait_to_confirm=wait_to_confirm,
         )
         return self._place_order_oapg(
+            body=args.body,
             query_params=args.query,
             path_params=args.path,
         )
